;*****************************************************************************
;* File Name          : USART_Init.INC
;* Author             : GRAND LOTUS
;* Version            : V1.00
;* Date               : 2019/07/01
;*****************************************************************************
;
;USART初始化
;
;*****************************************************************************
;//***************************************************************************
;//TXCR 发送控制寄存器
;//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
;//TXCR 发送控制寄存器
; ; Bit 7 TXEN: 使能发送
; ; 1 = 使能USART发送功能
; ; 0 = 屏蔽USART发送功能
; ; Bit 6 TMCLR: 发送寄存器空标志
; ; 1 = 数据已发送，移位寄存器空
; ; 0 = 正在发送数据，移位寄存器不空
; ; Bit 5 SYNC: 同步模式
; ; 1 = 选择同步模式
; ; 0 = 选择异步模式
; ; Bit 4 TX9: 数据长度选择
; ; 1 = 9位数据
; ; 0 = 8位数据
; ; Bit 3 SLAVE: 同步发送/接收模式
; ; 1 = SLAVE
; ; 0 = Master
; ; Bit[2:1] SPD[1:0]: 发送接收速度选择
; ; SPD[1:0] 波特率分频比(n)
; ; 11 256
; ; 10 64
; ; 01 16
; ; 00 4
; ; Bit 0 TXD9: 发送数据第9位数据

#define             TXEN_0               B'00000000'             ;//屏蔽USART发送功能
#define             TXEN_1               B'10000000'             ;//使能USART发送功能
#define             TMCLR_0              B'00000000'             ;//数据已发送，移位寄存器空
#define             TMCLR_1              B'01000000'             ;//正在发送数据，移位寄存器不空
#define             SYNC_0               B'00000000'             ;//选择异步模式
#define             SYNC_1               B'00100000'             ;//选择同步模式
#define             TX9_0                B'00000000'             ;//8位数据
#define             TX9_1                B'00010000'             ;//9位数据
#define             SLAVE_0              B'00000000'             ;// Master
#define             SLAVE_1              B'00001000'             ;// SLAVE
#define             SPD_0                B'00000000'             ;//波特率分频比4
#define             SPD_1                B'00000010'             ;//波特率分频比16
#define             SPD_2                B'00000100'             ;//波特率分频比64
#define             SPD_3                B'00000110'             ;//波特率分频比256
#define             TXD9_0               B'00000000'             ;// 发送0
#define             TXD9_1               B'00000001'             ;// 发送1

;//***************************************************************************
;//TXCR 发送控制寄存器
;//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
; ; Bit 7 RXEN: 使能接收
; ; 1 = 使能USART接收功能
; ; 0 = 屏蔽USART接收功能
; ; Bit 6 CKPS：同步模式时钟模式选择
; ; 1 = 下降沿发送数据
; ; 0 = 上升沿发送数据
; ; Bit 4 RX9: 数据长度选择
; ; 1 = 9位数据
; ; 0 = 8位数据
; ; Bit 3 SREN: 同步接收开始
; ; 1 = 开始同步接收，单字节接收模式下接收完一个字节自动清零
; ; 0 = 停止同步接受
; ; Bit 2 RXOVF: 接受缓冲区溢出标志
; ; 1 = 接收缓冲区溢出，读缓冲区自动清零
; ; 0 = 接收缓冲区未发生溢出
; ; Bit 1 FRER: 接收数据格式错
; ; 1 = 当前接收数据格式错（未收到停止位）
; ; 0 = 当前接收数据未发生格式错
; ; Bit 0 RXD9: 发送数据第9位数据

#define             RXEN_0               B'00000000'             ;//屏蔽USART接收功能
#define             RXEN_1               B'10000000'             ;//使能USART接收功能
#define             CKPS_0               B'00000000'             ;//上升沿发送数据
#define             CKPS_1               B'01000000'             ;//下降沿发送数据
#define             RX9_0                B'00000000'             ;// 8位数据
#define             RX9_1                B'00010000'             ;// 9位数据
#define             SREN_0               B'00000000'             ;//开始同步接收，单字节接收模式下接收完一个字节自动清零
#define             SREN_1               B'00001000'             ;//停止同步接受
#define             RXOVF_0              B'00000000'             ;//接收缓冲区溢出，读缓冲区自动清零
#define             RXOVF_1              B'00000100'             ;//接收缓冲区未发生溢出
#define             FRER_0               B'00000000'             ;//当前接收数据格式错（未收到停止位）
#define             FRER_1               B'00000010'             ;//当前接收数据未发生格式错
#define             RXD9_0               B'00000000'             ;// 接收0
#define             RXD9_1               B'00000001'             ;// 接收1


;*************************************************************************
;============================	串口初始化	==============================
;*************************************************************************

USART_Init:
;//1.端口设置
		;//   IOB3   TX
		;//   IOB4   RX
		;//  【将接收口（RX）改为输入状态】
		BSET		OEB,3		;//0:输入 1:输出
		BCLR		OEB,4		;//0:输入 1:输出
		
;//2.TXCR 设置	
		;//使能USART发送功能,8位数据,波特率分频比4,第9位数据发送0
		MOVIA		TXEN_1+TX9_0+SPD_0+TXD9_0	
		MOVAR		TXCR
		
;//3.RXCR 设置	
		;//使能USART接收功能,8位数据,第9位数据接收0
		MOVIA		RXEN_1+RX9_0+RXD9_0			
		MOVAR		RXCR

;//4.波特率设置
		MOVIA		 0x00
	    MOVAR		 BRGDH
	    MOVIA		 0x67		
	    MOVAR		 BRGDL		  ;波特率 38400	,目标波特率 = Fosc/（（BRGD+1）×n）

; ;//----------------------------------------------------      
; ;//Init 中断 

        BCLR		INTF0,RXIF    ;//清中断标志
		BCLR		INTF0,TXIF    ;//清中断标志
		BSET		INTCR0,RXIE    ;//使能串行通讯接收中断
        BCLR		INTCR0,TXIE	;//屏蔽串行通讯发送中断
		BSET		OPTION,GIE     ;//总中断使能
        RETURN
;*********************************END OF FILE**********************************		
